Index: src/gpu/GrPathUtils.cpp |
diff --git a/src/gpu/GrPathUtils.cpp b/src/gpu/GrPathUtils.cpp |
index 5fead5dea26153c5473dbd70b28eb0ec09310564..81921e36c8419d6193067aab71c03ed8511e9bd8 100644 |
--- a/src/gpu/GrPathUtils.cpp |
+++ b/src/gpu/GrPathUtils.cpp |
@@ -14,8 +14,8 @@ SkScalar GrPathUtils::scaleToleranceToSrc(SkScalar devTol, |
const SkMatrix& viewM, |
const SkRect& pathBounds) { |
// In order to tesselate the path we get a bound on how much the matrix can |
- // stretch when mapping to screen coordinates. |
- SkScalar stretch = viewM.getMaxStretch(); |
+ // scale when mapping to screen coordinates. |
+ SkScalar stretch = viewM.getMaxScale(); |
SkScalar srcTol = devTol; |
if (stretch < 0) { |